from django.http import HttpResponse, Http404, HttpResponseRedirect
from django.template import RequestContext, loader
from django.shortcuts import render, get_object_or_404
from django.core.urlresolvers import reverse
from django.views.decorators.csrf import csrf_exempt
import json

from polls.models import Poll, Choice

def index(request):
    latest_poll_list = Poll.objects.all().order_by('-pub_date')[:5]
    context = {'latest_poll_list': latest_poll_list}
    return render(request, 'polls/index.html', context)

def detail(request, poll_id):
    poll = get_object_or_404(Poll, pk=poll_id)
    return render(request, 'polls/detail.html', {'poll': poll})

def results(request, poll_id):
    poll = get_object_or_404(Poll, pk=poll_id)
    return render(request, 'polls/results.html', {'poll': poll})

def vote(request, poll_id):
    p = get_object_or_404(Poll, pk=poll_id)
    try:
        selected_choice = p.choice_set.get(pk=request.POST['choice'])
        print request.POST['choice']
    except (KeyError, Choice.DoesNotExist):
        # Redisplay the poll voting form.
        return render(request, 'polls/detail.html', {
            'poll': p,
            'error_message': "You didn't select a choice.",
        })
    else:
        selected_choice.votes += 1
        selected_choice.save()
        # Always return an HttpResponseRedirect after successfully dealing
        # with POST data. This prevents data from being posted twice if a
        # user hits the Back button.
        return HttpResponseRedirect(reverse('polls:results', args=(p.id,)))

@csrf_exempt    
def voteandroid(request, poll_id):
    p = get_object_or_404(Poll, pk=poll_id)
    print 'Post from Android'
    try:
        data=json.loads(request.body)
        label=data['choice']
        selected_choice = p.choice_set.get(pk=label)
        print 'User made choice with ID ' + label + ': ' 
        print selected_choice
    except:
        print 'Exception: Could not parse JSON'
    
    selected_choice.votes += 1
    selected_choice.save()
    #return HttpResponseRedirect(reverse('polls:results', args=(p.id,)))
    return HttpResponse('')

@csrf_exempt
def sendandroid(request, poll_id):
    # not ideal: ids have to be in order (1,2,3,4,...)
    # otherwise might give errors
    p = get_object_or_404(Poll, pk=poll_id)
    selected_choice = p.choice_set.get(pk='1')
    choices = p.choice_set.all()
    num= p.choice_set.count() # get number of choices
    response_data = {}
    for i in range(num):
        selected_choice = p.choice_set.get(pk=i+1)
        response_data[i+1]=selected_choice.votes
    return HttpResponse(json.dumps(response_data), content_type="application/json")

@csrf_exempt
def resetandroid(request, poll_id):
    p = get_object_or_404(Poll, pk=poll_id)
    num= p.choice_set.count() # get number of choices
    for i in range(num):
        selected_choice = p.choice_set.get(pk=i+1)
        selected_choice.votes = 0
        selected_choice.save()
    return HttpResponse("All Results Reset")

        
